@@ -26,6 +26,7 @@ using System.IO;
 using System.Web.Services;
 //using System.Web;
 using System.Web;
+using System.Collections; //ArrayList
 
 using System.Net; //getIP stuff
 
@@ -63,11 +64,11 @@ public class ChronojumpServer {
 	public bool CanINew(string action, string clientVersion)
 	{
 		Version cv = new Version(clientVersion);
-		if(action == Constants.ServerActionUploadSession && cv >= new Version(0,8,11))
+		if(action == Constants.ServerActionUploadSession && cv >= new Version(0,8,18))
 			return true;
-		else if(action == Constants.ServerActionStats && cv >= new Version(0,8))
+		else if(action == Constants.ServerActionStats && cv >= new Version(0,8,18))
 			return true;
-		else if(action == Constants.ServerActionQuery && cv >= new Version(0,8,9,6))
+		else if(action == Constants.ServerActionQuery && cv >= new Version(0,8,18))
 			return true;
 
 		return false;
@@ -86,7 +87,7 @@ public class ChronojumpServer {
 		else 
 			return false; //"for if the flyes"
 
-		if(action == Constants.ServerActionUploadSession && cv >= new Version(0,8,9,6))
+		if(action == Constants.ServerActionUploadSession && cv >= new Version(0,8,17))
 			return true;
 		else if(action == Constants.ServerActionStats && cv >= new Version(0,8))
 			return true;
@@ -99,11 +100,11 @@ public class ChronojumpServer {
 	[WebMethod(Description="Query")]
 	public string Query(string tableName, string test, string variable,
 			int sex, string ageInterval,
-			int countryID, int sportID, int speciallityID, int levelID)
+			int countryID, int sportID, int speciallityID, int levelID, int evaluatorID)
 	{
-		string str = Util.SQLBuildString(tableName, test, variable,
+		string str = Sqlite.SQLBuildQueryString(tableName, test, variable,
 				sex, ageInterval, 
-				countryID, sportID, speciallityID, levelID
+				countryID, sportID, speciallityID, levelID, evaluatorID
 				);
 
 		return SqliteServer.Query(str);
@@ -114,7 +115,7 @@ public class ChronojumpServer {
 	public string [] Stats()
 	{
 		string [] stats = SqliteServer.Stats();
-
+		
 		return stats;	
 	}
 
@@ -125,6 +126,12 @@ public class ChronojumpServer {
 	
 		int id = mySession.InsertAtDB(false, Constants.SessionTable);
 	
+		try {
+			File.Create("need-to-update-r-graphs");
+		} catch {
+			//file exists and cannot be overwritten
+		}
+	
 		return id; //uniqueID of person at server
 	}
 	
@@ -269,8 +276,9 @@ public class ChronojumpServer {
 		//change value for being inserted with new numeration in server
 		myPerson.UniqueID = -1;
 		
-		//hidden person.Name
+		//hidden person.Name and comments
 		myPerson.Name = "";
+		myPerson.Description = "";
 		
 		//do insertion
 		int id = myPerson.InsertAtDB(false, Constants.PersonTable);
@@ -284,11 +292,11 @@ public class ChronojumpServer {
 	}
 	
 	[WebMethod(Description="Upload person session if needed")]
-	public int UploadPersonSessionIfNeeded(int personServerID, int sessionServerID, int weight)
+	public int UploadPersonSessionIfNeeded(PersonSession ps)
 	{
-		if(!SqlitePersonSession.PersonSelectExistsInSession(personServerID, sessionServerID)) {
+		if(!SqlitePersonSession.PersonSelectExistsInSession(ps.PersonID, ps.SessionID)) {
 			Console.WriteLine("personSession needed");
-			SqlitePersonSession.Insert (personServerID, sessionServerID, weight);
+			ps.InsertAtDB(false, Constants.PersonSessionTable);
 			Console.WriteLine("done");
 			return 1; //unused
 		} else 
@@ -410,6 +418,14 @@ public class ChronojumpServer {
 		return false;
 	}
 
+	[WebMethod(Description="Select evaluators")]
+	public string [] SelectEvaluators(bool addAnyString)
+	{
+		Console.WriteLine("select evaluators");
+
+		return SqliteServer.SelectEvaluators(addAnyString);
+	}
+
 
 /*
 	[WebMethod(Description="Upload a test")]
