@@ -16,7 +16,7 @@
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Copyright (C) 2008   Sharad Shankar & Onkar Nath Mishra http://www.logicbrick.com/
- * Copyright (C) 2008   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2008-2010   Xavier de Blas <xaviblas@gmail.com> 
  *
  */
 
@@ -24,12 +24,12 @@
 
 #include "opencv/cv.h"
 #include "opencv/highgui.h"
-#include <opencv/cxcore.h>
+//#include <opencv/cxcore.h>
 #include "stdio.h"
 #include "math.h"
-#include<iostream>
-#include<fstream>
-#include<vector>
+//#include<iostream>
+//#include<fstream>
+//#include<vector>
 #include <string>
 
 
@@ -65,7 +65,7 @@ CvPoint findHipPoint(IplImage* img,CvRect roirect)
 	CvPoint pt;
 	pt.x =0;pt.y=0;
 	int starty = roirect.y;
-	int endy = starty + roirect.height*2/3; /* meu: why 2/3 */
+	int endy = starty + roirect.height*2/3; /* meu: why 2/3?... because have to be in the 2/3 up image*/
 	CvMat *srcmat,src_stub;
 	srcmat = cvGetMat(img,&src_stub);
 	uchar *srcdata = srcmat->data.ptr;
@@ -113,28 +113,31 @@ CvPoint findHipPoint(IplImage* img,CvRect roirect)
 }
 
 /*
- * takes as input arguement the bounding rectangle of the largest contour,the image containing the bounding rectangle and the y coordinate of the hip point
+ * takes as input argument the bounding rectangle of the largest contour,the image containing the bounding rectangle and the y coordinate of the hip point
  * Calculates the knee point
  * Knee point is a white pixel below the hip point and having maximum x coordinate in the bounding box
  * Returns the coordinate of the knee point
  */
-CvPoint findKneePointFront(IplImage *img,CvRect roirect,int starty, bool foundAngleOneTime)
+CvPoint findKneePointFront(IplImage *img, CvRect roirect, int rectHMax)
 {
 	CvPoint pt;
 	pt.x = 0; pt.y = 0;
 	
-	//int endy = roirect.y+roirect.height*9/10; //this is ok if shoes or platform is shown in standup image
-	int endy = roirect.y+roirect.height;
+	int starty = roirect.y;
+	int endy = roirect.y+roirect.height*8/10;
 	
+	//if person is totally in extension, don't try to find kneePointFront and back,
+	//because there's lot of error because quadriceps is in front
+	if(roirect.height >= .97 * rectHMax) {
+		return pt;
+	}
 	/*
-	 * if we never found and angle before, knee must be more or less at the middle. 
-	 * Is important to find it at start of flexion, to try to get the kneeCenter at (close to extension)
-	 * and use it's X for hipPoint and backLength.
-	 * For this reason, now we only search in the middle of the image
+	 * if person is in extension, knee must be more or less at the middle. 
+	 * we are in extension because roirect.height >= 85% rectHMax
 	 */
-	if(! foundAngleOneTime) {
-		starty = roirect.y + roirect.height*1/3;
-		endy = roirect.y + roirect.height*2/3;
+	if(roirect.height >= .85 * rectHMax) {
+		starty = roirect.y + roirect.height*2/5;
+		endy = roirect.y + roirect.height*4/5;
 	}
 
 	CvMat *srcmat,src_stub;
@@ -183,11 +186,12 @@ CvPoint findKneePointFront(IplImage *img,CvRect roirect,int starty, bool foundAn
 }
 
 //hueco popliteo
-CvPoint findKneePointBack(IplImage *img,CvRect roirect,int starty, int kneePointFrontX, bool foundAngleOneTime)
+CvPoint findKneePointBack(IplImage *img, CvRect roirect, int kneePointFrontX, int rectHMax)
 {
 	CvPoint pt;
 	pt.x = 0; pt.y = 0;
 
+	int starty = roirect.y;
 	/*
 	 * this 8/10 makes no error when jump starts, 
 	 * if not, on jump, the bottom of the pants can be taken as kneeBack
@@ -196,8 +200,13 @@ CvPoint findKneePointBack(IplImage *img,CvRect roirect,int starty, int kneePoint
 	/*
 	 * same as finddKneePointFront
 	 */
-	if(! foundAngleOneTime)
-		endy = roirect.y + roirect.height*2/3;
+	if(roirect.height >= .97 * rectHMax) {
+		return pt;
+	}
+	if(roirect.height >= .85 * rectHMax) {
+		starty = roirect.y + roirect.height*2/5;
+		endy = roirect.y + roirect.height*4/5;
+	}
 
 	CvMat *srcmat,src_stub;
 	srcmat = cvGetMat(img,&src_stub);
@@ -345,7 +354,10 @@ CvPoint findToePoint(IplImage *img,CvRect roirect,int startx,int starty, int toe
  * imgH (image Holes)
  */
 CvSeq* findHoles(IplImage *imgC, IplImage *imgH, IplImage *foundHoles, IplImage *imgMain, 
-	CvRect roirect, CvPoint hipOld, CvPoint kneeOld, CvPoint toeOld)
+	CvRect roirect, 
+	CvPoint hipOld, CvPoint kneeOld, CvPoint toeOld, 
+	CvPoint hipPredicted, CvPoint kneePredicted, CvPoint toePredicted, 
+	CvFont font)
 {
 	CvPoint pt;
 	pt.x =0;pt.y=0;
@@ -391,7 +403,7 @@ CvSeq* findHoles(IplImage *imgC, IplImage *imgH, IplImage *foundHoles, IplImage
 			}
 		}
 	}
-
+						
 	//assign each point to a group (a hole)
 	for( int i = 0; i < seqPoints->total; i++ ) {
 		CvPoint pt = *CV_GET_SEQ_ELEM( CvPoint, seqPoints, i ); 
@@ -500,6 +512,8 @@ CvSeq* findHoles(IplImage *imgC, IplImage *imgH, IplImage *foundHoles, IplImage
 	CvPoint kneePoint;
 	CvPoint toePoint;
 	hipPoint.x=0; kneePoint.x=0; toePoint.x=0;
+	char *labelShort = new char[2];
+	CvScalar color = CV_RGB(128, 128, 128 ); //paint rectangles in not-valid (or not big) holes.
 	for( int i = 0; i < seqHolesSize->total; i++ ) 
 	{
 		int validSize = *CV_GET_SEQ_ELEM( int, seqIsValidSize, i ); 
@@ -516,34 +530,81 @@ CvSeq* findHoles(IplImage *imgC, IplImage *imgH, IplImage *foundHoles, IplImage
 				if(size == sizeBig1 || size == sizeBig2 || size == sizeBig3)
 					validSure = true;
 			} 
-			//if found a point before, and this point is inside before point (ok at 300 fps)
+			//if found a point before, and this point is where it's predicted, or inside the before point (ok at 300 fps)
 			//a point is also ok, if we come from a user forward (then, there's not need to be inside old point)
-			else if (pointInside(hipOld, sp1, sp2) || pointInside(kneeOld, sp1,sp2) || pointInside(toeOld, sp1,sp2))
+			else if (pointInside(hipPredicted, sp1, sp2) || pointInside(kneePredicted, sp1,sp2) || pointInside(toePredicted, sp1,sp2)
+					|| (pointInside(hipOld, sp1, sp2) || pointInside(kneeOld, sp1,sp2) || pointInside(toeOld, sp1,sp2)))
 				validSure = true;
 		}
 
 		if(validSure) {
 			CvPoint center = *CV_GET_SEQ_ELEM( CvPoint, seqHolesCenter, i ); 
-			if(hipPoint.x == 0) {
-				cvRectangle(imgMain, 
-						cvPoint(sp1.x-1,sp1.y-1),
-						cvPoint(sp2.x+1, sp2.y+1),
-						CV_RGB(0,255,0),1,1);
-				hipPoint.x = center.x; hipPoint.y = center.y;
-			} else if(kneePoint.x == 0) {
-				cvRectangle(imgMain, 
-						cvPoint(sp1.x-1,sp1.y-1),
-						cvPoint(sp2.x+1, sp2.y+1),
-						CV_RGB(0,255,0),1,1);
-				kneePoint.x = center.x; kneePoint.y = center.y;
+
+			//the point will be hip knee or toe depending on the distance betwee old hip, knee & toe
+			//but give preference to the top (<=) because will be the first to be found (top to bottom)
+			int pointIs = TOGGLENOTHING;
+			if(!pointIsNull(hipOld) && !pointIsNull(kneeOld) && !pointIsNull(toeOld)) {
+				int hipDist = getDistance(center, hipOld);
+				int kneeDist = getDistance(center, kneeOld);
+				int toeDist = getDistance(center, toeOld);
+				if(hipPoint.x == 0) {
+					if(hipDist <= kneeDist) {
+						if(hipDist <= toeDist)
+							pointIs = TOGGLEHIP;
+						else
+							pointIs = TOGGLETOE;
+					} else {
+						if(kneeDist <= toeDist)
+							pointIs = TOGGLEKNEE;
+						else
+							pointIs = TOGGLETOE;
+					}
+				} else if(kneePoint.x == 0) {
+					if(kneeDist <= toeDist)
+						pointIs = TOGGLEKNEE;
+					else
+						pointIs = TOGGLETOE;
+				} else if(toePoint.x == 0) 
+					pointIs = TOGGLETOE;
 			} else {
+				if(hipPoint.x == 0)
+					pointIs = TOGGLEHIP;
+				else if(kneePoint.x == 0) 
+					pointIs = TOGGLEKNEE;
+				else // if(toePoint.x == 0) 
+					pointIs = TOGGLETOE;
+			}
+
+			if(pointIs == TOGGLEHIP) {
+				color = RED; 
 				cvRectangle(imgMain, 
 						cvPoint(sp1.x-1,sp1.y-1),
 						cvPoint(sp2.x+1, sp2.y+1),
-						CV_RGB(0,255,0),1,1);
+						color,1,1);
+				hipPoint.x = center.x; hipPoint.y = center.y;
+				sprintf(labelShort,"H");
+			} 
+			else if(pointIs == TOGGLEKNEE) {
+				color = GREEN; 
+				cvRectangle(imgMain, 
+						cvPoint(sp1.x-1,sp1.y-1),
+						cvPoint(sp2.x+1, sp2.y+1),
+						color,1,1);
+				kneePoint.x = center.x; kneePoint.y = center.y;
+				sprintf(labelShort,"K");
+			} 
+			else {
+				color = BLUE; 
+				cvRectangle(imgMain, 
+						cvPoint(sp1.x-1,sp1.y-1),
+						cvPoint(sp2.x+1, sp2.y+1),
+						color,1,1);
 				toePoint.x = center.x; toePoint.y = center.y;
+				sprintf(labelShort,"T");
 			}
-		} else {
+			imagePrint(imgMain, cvPoint(center.x + 20, center.y), labelShort, font, color);
+		} 
+		else {
 			 //paint rectangles in not-valid (or not big) holes.
 			cvRectangle(imgMain, 
 					cvPoint(sp1.x-1,sp1.y-1),
@@ -585,9 +646,13 @@ CvSeq* findHoles(IplImage *imgC, IplImage *imgH, IplImage *foundHoles, IplImage
 
 /*
  * this function is realy similiar to findHoles
+ * but this it doesn't search inside the contour
  * try to do only a function
  */
-CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, CvPoint hipOld, CvPoint kneeOld, CvPoint toeOld, CvFont font)
+CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, 
+		CvPoint hipOld, CvPoint kneeOld, CvPoint toeOld, 
+		CvPoint hipPredicted, CvPoint kneePredicted, CvPoint toePredicted, 
+		CvFont font)
 {
 	CvPoint pt;
 	pt.x =0;pt.y=0;
@@ -597,7 +662,6 @@ CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, CvPoint hipOld, Cv
 	uchar *srcdata = srcmat->data.ptr;
 	
 	int width = imgThresh->width;
-	int minx = imgThresh->width;
 	int endy = imgThresh->height;
 	
 	//stick storage
@@ -606,6 +670,7 @@ CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, CvPoint hipOld, Cv
 	CvSeq* seqPoints = cvCreateSeq( CV_SEQ_KIND_GENERIC|CV_32SC2, sizeof(CvSeq), sizeof(CvPoint), storage );
 	CvSeq* seqGroups = cvCreateSeq( 0, sizeof(CvSeq), sizeof(0), storage );
 
+	//printf("entering bucle");
 	
 	//put all hole points on seqAllHoles
 	for(int y=0;y<endy;y++)
@@ -623,6 +688,21 @@ CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, CvPoint hipOld, Cv
 		}
 	}
 
+	//printf("points: %d", seqPoints->total);
+	//cvWaitKey(500); //to allow points num to be shown
+	CvSeq* seqHolesEnd = cvCreateSeq( CV_SEQ_KIND_GENERIC|CV_32SC2, sizeof(CvSeq), sizeof(CvPoint), storage );
+	
+	if(seqPoints->total > 50000) {
+		CvPoint ptNull;
+		ptNull.x = 0;
+		ptNull.y = 0;
+		cvSeqPush( seqHolesEnd, &ptNull );
+		cvSeqPush( seqHolesEnd, &ptNull );
+		cvSeqPush( seqHolesEnd, &ptNull );
+		return seqHolesEnd;
+	}
+
+
 	//assign each point to a group (a hole)
 	for( int i = 0; i < seqPoints->total; i++ ) {
 		CvPoint pt = *CV_GET_SEQ_ELEM( CvPoint, seqPoints, i ); 
@@ -639,7 +719,6 @@ CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, CvPoint hipOld, Cv
 	CvSeq* seqHolesSize = cvCreateSeq( 0, sizeof(CvSeq), sizeof(0), storage );
 	
 
-
 	for( int i = 0; i <= getMaxValue(seqGroups); i++ ) {
 		int maxX = -1;
 		int minX = 10000;
@@ -765,23 +844,23 @@ CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, CvPoint hipOld, Cv
 					}
 				}
 			}
-			//if found a point before, and this point is inside before point (ok at 300 fps)
+			//if found a point before, and this point is where it's predicted, or inside the before point (ok at 300 fps)
 			//a point is also ok, if we come from a user forward (then, there's not need to be inside old point)
 			else {
 				validSure = true;
-				if(pointInside(hipOld, sp1, sp2)) {
+				if(pointInside(hipPredicted, sp1, sp2) || pointInside(hipOld, sp1, sp2)) {
 					hipPoint.x = center.x; 
 					hipPoint.y = center.y;
 					color = RED;
 					sprintf(labelShort,"H");
 				} 
-				else if(pointInside(kneeOld, sp1,sp2)) {
+				else if(pointInside(kneePredicted, sp1, sp2) || pointInside(kneeOld, sp1, sp2)) {
 					kneePoint.x = center.x; 
 					kneePoint.y = center.y;
 					color = GREEN;
 					sprintf(labelShort,"K");
 				} 
-				else if(pointInside(toeOld, sp1,sp2)) {
+				else if(pointInside(toePredicted, sp1, sp2) || pointInside(toeOld, sp1, sp2)) {
 					toePoint.x = center.x; 
 					toePoint.y = center.y;
 					color = BLUE;
@@ -833,7 +912,7 @@ CvSeq* findHolesSkin(IplImage *imgThresh, IplImage *imgColor, CvPoint hipOld, Cv
 	CvPoint notFoundPoint;
 	notFoundPoint.x = 0; notFoundPoint.y = 0;
 
-	CvSeq* seqHolesEnd = cvCreateSeq( CV_SEQ_KIND_GENERIC|CV_32SC2, sizeof(CvSeq), sizeof(CvPoint), storage );
+//	CvSeq* seqHolesEnd = cvCreateSeq( CV_SEQ_KIND_GENERIC|CV_32SC2, sizeof(CvSeq), sizeof(CvPoint), storage );
 
 	if(hipPoint.x > 0) 
 		cvSeqPush( seqHolesEnd, &hipPoint );
@@ -1013,7 +1092,7 @@ CvPoint fixHipPoint2(IplImage* img, int hipY, CvPoint knee, CvPoint ptHK)
 	HCenter.x = ( (kneePrima.x / (double)kneePrima.y) * HCenter.y ) - d;
 
 	/*
-	if(debug) {
+	if(Debug) {
 		printf("hipy(%d) ",hipY);
 		printf("knee(%d,%d) ",knee.x, knee.y);
 		printf("ptHK(%d,%d) ",ptHK.x, ptHK.y);
@@ -1146,11 +1225,15 @@ int calculateBrightness(IplImage* img)
 		return (int) 100 * countBlack/(countWhite + countBlack);
 }
 
-int calculateThresholdStart(IplImage * gray)
+//true means find the black pants.
+//false means find the points
+//TODO: in the future put values of min or max regarding on statistics of analyzed jumps
+int calculateThresholdStart(IplImage * gray, bool pantsOrPoints)
 {
 	int brightness = calculateBrightness(gray);
 	printf("brightness: %d\n", brightness);
 
+	//PANTS INFO:
 	//created image like the contour but with holes and more (stores on segmentedValidationHoles)
 	//recommended 25,255
 	//high threshold (40-60) detects more black things (useful to not confuse a hole when is close to the border)
@@ -1159,39 +1242,72 @@ int calculateThresholdStart(IplImage * gray)
 	//int threshold = 35;
 	//put threshold min depending on brightnesss
 	//eg: nora: brightness 85 -> threshold 30
-	//eg: 44_lluis_puerta_salt6_m.MOV: brightness 73 -> threshold 10
+	//eg: 44_-_salt6_m.MOV: brightness 73 -> threshold 10
 
 	//adjust better, because:
-	//12_carles_tejedor_salt3_m.MOV
+	//12_-_salt3_m.MOV
 	//is bright:0, but if put thresh to 1 then detects bad. and to 10 is ok
 	//
-	//on the other side, 2_roger_miralles_salt3_m.MOV
+	//on the other side, 2_-_salt3_m.MOV
 	//is really dark and it needs a thresh of 1 to work
 	//
 	//also it could be nice to have a thresh that detects three objects
 	//another option, could be to have the thresh 10 as really minimum and darker images are unsupported!
+
+	//POINTS INFO:
+	//normal threshold for points is 150, but can be modified depending on brightness
+
 	int thresholdStart;
 	int briMax = 85;
 	int briMin = 65;
 	//int briZero = 50;
 	int thresMax = 30;
-	int thresMin = 10;
+	int thresMin = 1;
+	if(!pantsOrPoints) { //threshold for points
+		thresMax = 190;
+		thresMin = 100;
+	}
 
 	if(brightness >= briMax) 
 		thresholdStart = thresMax;
+	//pants
 	//else if(brightness <= briZero)
 	//	thresholdStart = 10;
 	else if(brightness <= briMin)
 		thresholdStart = thresMin;
-	else
-		thresholdStart = brightness - briMin + thresMin;
+	else {
+		//thresholdStart = brightness - briMin + thresMin;
+
+		/*
+		   if briMin = 65, briMax = 85
+		   threshMin = 100, thresMax = 190
+		   a brightness of 82 means 85% of brightness. This will have a 85% of threshold: 176
+		*/
+
+		//85 - 65 = 20
+		int briRang = briMax - briMin;
+		//82 - 65 = 17
+		int briToMin = brightness - briMin;
+		//100 * 17 / 20 = 85
+		double briPercent = 100 * briToMin / briRang;
+
+		//190 - 100 = 90
+		int thresRang = thresMax - thresMin;
+		//100 * x / 90 = 85
+		//x = 85 * 90 /100
+		//x = 76.5
+		int thresPercentValue = briPercent * thresRang / 100;
+
+		//76,5 + 100 = (int) 176,5 = 176
+		thresholdStart = thresPercentValue + thresMin;
+	}
 
 	return thresholdStart;
 }
 
 IplImage * zoomImage(IplImage *img) {
-	IplImage* imgZoom = cvCreateImage( cvSize( cvRound (img->width*zoomScale), 
-				cvRound (img->height*zoomScale)), 8, 3 );
+	IplImage* imgZoom = cvCreateImage( cvSize( cvRound (img->width*ZoomScale), 
+				cvRound (img->height*ZoomScale)), 8, 3 );
 	cvResize( img, imgZoom, CV_INTER_LINEAR );
 	return imgZoom;
 }
@@ -1201,21 +1317,22 @@ void on_mouse_gui_menu( int event, int x, int y, int flags, void* param )
 	CvPoint clicked; 
 	clicked.x=x; clicked.y=y;
 
-	CvRect rval; rval.x=60;  rval.width=60;  rval.y=60; rval.height=210;
-	CvRect rbam; rbam.x=188; rbam.width=100; rbam.y=60; rbam.height=210;
-	CvRect rsom; rsom.x=340; rsom.width=90;  rsom.y=60; rsom.height=210;
+	CvRect rval; rval.x=45;  rval.width=70;  rval.y=60; rval.height=210;
+	CvRect rbwm; rbwm.x=200; rbwm.width=70; rbwm.y=60; rbwm.height=210;
+	CvRect rsom; rsom.x=360; rsom.width=70;  rsom.y=60; rsom.height=210;
+
 	CvRect rquit; rquit.x=450; rquit.width=40;  rquit.y=10; rquit.height=45;
 	switch( event ) {
 		case CV_EVENT_LBUTTONDOWN:
 			{
 				if(pointInsideRect(clicked, rval))
-					mouseClicked = validation;
-				else if(pointInsideRect(clicked, rbam))
-					mouseClicked = blackWithoutMarkers;
+					MouseClicked = validation;
+				else if(pointInsideRect(clicked, rbwm))
+					MouseClicked = blackWithoutMarkers;
 				else if(pointInsideRect(clicked, rsom))
-					mouseClicked = skinOnlyMarkers;
+					MouseClicked = skinOnlyMarkers;
 				else if(pointInsideRect(clicked, rquit))
-					mouseClicked = quit;
+					MouseClicked = quit;
 			}
 			break;
 	}
@@ -1227,73 +1344,144 @@ void on_mouse_gui( int event, int x, int y, int flags, void* param )
 	clicked.x=x; clicked.y=y;
 
 	CvRect rplaypause; rplaypause.x=220; rplaypause.width=60;  rplaypause.y=38; rplaypause.height=42;
-	CvRect rforward; rforward.x=290; rforward.width=60;  rforward.y=38; rforward.height=42;
-	CvRect rfastforward; rfastforward.x=360; rfastforward.width=60;  rfastforward.y=38; rfastforward.height=42;
+	CvRect rforwardOne; rforwardOne.x=290; rforwardOne.width=36;  rforwardOne.y=38; rforwardOne.height=42;
+	CvRect rforward; rforward.x=330; rforward.width=47;  rforward.y=38; rforward.height=42;
+	CvRect rfastforward; rfastforward.x=380; rfastforward.width=41;  rfastforward.y=38; rfastforward.height=42;
 	CvRect rbackward; rbackward.x=430; rbackward.width=60;  rbackward.y=38; rbackward.height=42;
 	
-	CvRect rhip; rhip.x=165; rhip.width=25;  rhip.y=130; rhip.height=24;
-	CvRect rknee; rknee.x=235; rknee.width=25;  rknee.y=130; rknee.height=24;
-	CvRect rtoe; rtoe.x=308; rtoe.width=25;  rtoe.y=130; rtoe.height=24;
-	CvRect rzoom; rzoom.x=447; rzoom.width=25;  rzoom.y=130; rzoom.height=24;
+	CvRect rhip; rhip.x=165; rhip.width=25;  rhip.y=114; rhip.height=24;
+	CvRect rknee; rknee.x=235; rknee.width=25;  rknee.y=114; rknee.height=24;
+	CvRect rtoe; rtoe.x=308; rtoe.width=25;  rtoe.y=114; rtoe.height=24;
+	CvRect rzoom; rzoom.x=447; rzoom.width=25;  rzoom.y=114; rzoom.height=24;
 	
-	CvRect rthipmore; rthipmore.x=149; rthipmore.width=24;  rthipmore.y=169; rthipmore.height=24;
-	CvRect rthipless; rthipless.x=181; rthipless.width=27;  rthipless.y=169; rthipless.height=24;
-	CvRect rtkneemore; rtkneemore.x=219; rtkneemore.width=24;  rtkneemore.y=169; rtkneemore.height=24;
-	CvRect rtkneeless; rtkneeless.x=251; rtkneeless.width=27;  rtkneeless.y=169; rtkneeless.height=24;
-	CvRect rttoemore; rttoemore.x=293; rttoemore.width=24;  rttoemore.y=169; rttoemore.height=24;
-	CvRect rttoeless; rttoeless.x=324; rttoeless.width=27;  rttoeless.y=169; rttoeless.height=24;
-	CvRect rtglobalmore; rtglobalmore.x=433; rtglobalmore.width=24;  rtglobalmore.y=169; rtglobalmore.height=24;
-	CvRect rtgloballess; rtgloballess.x=464; rtgloballess.width=27;  rtgloballess.y=169; rtgloballess.height=24;
+	//thresholds
+	CvRect rthipmore; rthipmore.x=149; rthipmore.width=24;  rthipmore.y=150; rthipmore.height=24;
+	CvRect rthipless; rthipless.x=181; rthipless.width=27;  rthipless.y=150; rthipless.height=24;
+	CvRect rtkneemore; rtkneemore.x=219; rtkneemore.width=24;  rtkneemore.y=150; rtkneemore.height=24;
+	CvRect rtkneeless; rtkneeless.x=251; rtkneeless.width=27;  rtkneeless.y=150; rtkneeless.height=24;
+	CvRect rttoemore; rttoemore.x=293; rttoemore.width=24;  rttoemore.y=150; rttoemore.height=24;
+	CvRect rttoeless; rttoeless.x=324; rttoeless.width=27;  rttoeless.y=150; rttoeless.height=24;
+	CvRect rtglobalmore; rtglobalmore.x=433; rtglobalmore.width=24;  rtglobalmore.y=150; rtglobalmore.height=24;
+	CvRect rtgloballess; rtgloballess.x=464; rtgloballess.width=27;  rtgloballess.y=150; rtgloballess.height=24;
 	
+	//thresholds sizes
+	CvRect rshipmore; rshipmore.x=149; rshipmore.width=24;  rshipmore.y=186; rshipmore.height=24;
+	CvRect rshipless; rshipless.x=181; rshipless.width=27;  rshipless.y=186; rshipless.height=24;
+	CvRect rskneemore; rskneemore.x=219; rskneemore.width=24;  rskneemore.y=186; rskneemore.height=24;
+	CvRect rskneeless; rskneeless.x=251; rskneeless.width=27;  rskneeless.y=186; rskneeless.height=24;
+	CvRect rstoemore; rstoemore.x=293; rstoemore.width=24;  rstoemore.y=186; rstoemore.height=24;
+	CvRect rstoeless; rstoeless.x=324; rstoeless.width=27;  rstoeless.y=186; rstoeless.height=24;
+
+	//blackOnlyMarkers !UsingContour	
+	CvRect rbackToContour; rbackToContour.x=372; rbackToContour.width=118;  rbackToContour.y=186; rbackToContour.height=24;
+
+
 	CvRect rquit; rquit.x=450; rquit.width=40;  rquit.y=230; rquit.height=45;
 				
 	if(flags & CV_EVENT_FLAG_SHIFTKEY)
-		mouseMultiplier = true;
+		MouseMultiplier = true;
 	else 
-		mouseMultiplier = false;
+		MouseMultiplier = false;
+
+	if(flags & CV_EVENT_FLAG_CTRLKEY)
+		MouseControl = true;
+	else 
+		MouseControl = false;
 
 
+	bool success; //this helps to navigate between modes. Is not a return value
 	switch( event ) {
 		case CV_EVENT_LBUTTONDOWN:
 			{
+				//common controls
+				success = true;
 				if(pointInsideRect(clicked, rplaypause))
-					mouseClicked = PLAYPAUSE;
+					MouseClicked = PLAYPAUSE;
+				else if(pointInsideRect(clicked, rforwardOne))
+					MouseClicked = FORWARDONE;
 				else if(pointInsideRect(clicked, rforward))
-					mouseClicked = FORWARD;
+					MouseClicked = FORWARD;
 				else if(pointInsideRect(clicked, rfastforward))
-					mouseClicked = FASTFORWARD;
+					MouseClicked = FASTFORWARD;
 				else if(pointInsideRect(clicked, rbackward))
-					mouseClicked = BACKWARD;
-
-
+					MouseClicked = BACKWARD;
 				else if(pointInsideRect(clicked, rhip))
-					mouseClicked = HIPMARK;
+					MouseClicked = HIPMARK;
 				else if(pointInsideRect(clicked, rknee))
-					mouseClicked = KNEEMARK;
+					MouseClicked = KNEEMARK;
 				else if(pointInsideRect(clicked, rtoe))
-					mouseClicked = TOEMARK;
+					MouseClicked = TOEMARK;
 				else if(pointInsideRect(clicked, rzoom))
-					mouseClicked = ZOOM;
-
-				else if(pointInsideRect(clicked, rthipmore))
-					mouseClicked = THIPMORE;
-				else if(pointInsideRect(clicked, rthipless))
-					mouseClicked = THIPLESS;
-				else if(pointInsideRect(clicked, rtkneemore))
-					mouseClicked = TKNEEMORE;
-				else if(pointInsideRect(clicked, rtkneeless))
-					mouseClicked = TKNEELESS;
-				else if(pointInsideRect(clicked, rttoemore))
-					mouseClicked = TTOEMORE;
-				else if(pointInsideRect(clicked, rttoeless))
-					mouseClicked = TTOELESS;
-				else if(pointInsideRect(clicked, rtglobalmore))
-					mouseClicked = TGLOBALMORE;
-				else if(pointInsideRect(clicked, rtgloballess))
-					mouseClicked = TGLOBALLESS;
-
+					MouseClicked = ZOOM;
 				else if(pointInsideRect(clicked, rquit))
-					mouseClicked = QUIT;
+					MouseClicked = QUIT;
+				else 
+					success = false;
+
+				//blackOnlyMarkers with contour or validation
+				if(!success && ( ProgramMode == validation && UsingContour) ) {
+					success = true;
+					if(pointInsideRect(clicked, rtglobalmore))
+						MouseClicked = TCONTOURMORE;
+					else if(pointInsideRect(clicked, rtgloballess))
+						MouseClicked = TCONTOURLESS;
+					else
+						success = false;
+				}
+
+				//skinOnlyMarkers || (blackOnlyMarkers without contour)
+				if(!success && (ProgramMode == skinOnlyMarkers || 
+							(ProgramMode == validation && !UsingContour))) {
+					success = true;
+					if(pointInsideRect(clicked, rthipmore))
+						MouseClicked = THIPMORE;
+					else if(pointInsideRect(clicked, rthipless))
+						MouseClicked = THIPLESS;
+					else if(pointInsideRect(clicked, rtkneemore))
+						MouseClicked = TKNEEMORE;
+					else if(pointInsideRect(clicked, rtkneeless))
+						MouseClicked = TKNEELESS;
+					else if(pointInsideRect(clicked, rttoemore))
+						MouseClicked = TTOEMORE;
+					else if(pointInsideRect(clicked, rttoeless))
+						MouseClicked = TTOELESS;
+					else
+						success = false;
+				}
+				
+				if(!success && (ProgramMode == skinOnlyMarkers || 
+							(ProgramMode == validation && !UsingContour))) {
+					success = true;
+					if(pointInsideRect(clicked, rtglobalmore))
+						MouseClicked = TGLOBALMORE;
+					else if(pointInsideRect(clicked, rtgloballess))
+						MouseClicked = TGLOBALLESS;
+
+					else if(pointInsideRect(clicked, rshipmore))
+						MouseClicked = SHIPMORE;
+					else if(pointInsideRect(clicked, rshipless))
+						MouseClicked = SHIPLESS;
+					else if(pointInsideRect(clicked, rskneemore))
+						MouseClicked = SKNEEMORE;
+					else if(pointInsideRect(clicked, rskneeless))
+						MouseClicked = SKNEELESS;
+					else if(pointInsideRect(clicked, rstoemore))
+						MouseClicked = STOEMORE;
+					else if(pointInsideRect(clicked, rstoeless))
+						MouseClicked = STOELESS;
+					else
+						success = false;
+				}
+				
+				//only for blackOnlyMarkers without contour
+				if(!success && (ProgramMode == validation && !UsingContour)) {
+					success = true;
+					if(pointInsideRect(clicked, rbackToContour)) {
+						MouseClicked = BACKTOCONTOUR;
+					}
+					else
+						success = false;
+				}
 			}
 			break;
 	}
@@ -1301,9 +1489,9 @@ void on_mouse_gui( int event, int x, int y, int flags, void* param )
 
 void on_mouse_mark_point( int event, int x, int y, int flags, void* param )
 {
-	if(zoomed) {
-		x = x / zoomScale;
-		y = y / zoomScale;
+	if(Zoomed) {
+		x = x / ZoomScale;
+		y = y / ZoomScale;
 	}
 	
 	CvPoint clicked; 
@@ -1312,31 +1500,10 @@ void on_mouse_mark_point( int event, int x, int y, int flags, void* param )
 	switch( event ) {
 		case CV_EVENT_LBUTTONDOWN:
 			{
-				/*
-				if(forceMouseMark == TOGGLEHIP) 
-				{
-					//hipMouse = clicked;
-					markedMouse = clicked;
-					forceMouseHip = false;
-				} 
-				else if(forceMouseMark == TOGGLEKNEE) 
-				{
-					//kneeMouse = clicked;
-					markedMouse = clicked;
-					forceMouseKnee = false;
-				} 
-				else if(forceMouseMark == TOGGLETOE) 
-				{
-					//toeMouse = clicked;
-					markedMouse = clicked;
-					forceMouseToe = false;
-				} 
-				*/
-				
-				if(forceMouseMark == TOGGLEHIP || forceMouseMark == TOGGLEKNEE || 
-						forceMouseMark == TOGGLETOE) {
-					markedMouse = clicked;
-					forceMouseMark = TOGGLENOTHING;
+				if(ForceMouseMark == TOGGLEHIP || ForceMouseMark == TOGGLEKNEE || 
+						ForceMouseMark == TOGGLETOE) {
+					MarkedMouse = clicked;
+					ForceMouseMark = TOGGLENOTHING;
 				}
 			}
 			break;
@@ -1344,9 +1511,10 @@ void on_mouse_mark_point( int event, int x, int y, int flags, void* param )
 }
 
 void updateHolesWin(IplImage *segmentedValidationHoles) {
-	showScaledImage(segmentedValidationHoles, "holes");
+	showScaledImage(segmentedValidationHoles, "Holes_on_contour");
 }
 
+/* unused, 3D stuff
 void printOnScreen(IplImage * img, CvFont font, CvScalar color, bool labelsAtLeft, 
 		int framesCount, int threshold, double upLegMarkedDistPercent, double downLegMarkedDistPercent,
 		double thetaMarked, double minThetaMarked, 
@@ -1384,6 +1552,80 @@ void printOnScreen(IplImage * img, CvFont font, CvScalar color, bool labelsAtLef
 	cvPutText(img, label, cvPoint(x, height-20),&font,color);
 
 }
+*/
+		
+void printOnScreen(IplImage * img, CvFont font, CvScalar color, bool labelsAtLeft, 
+		int framesCount, 
+		int hip_x, int hip_y, int knee_x, int knee_y, int toe_x, int toe_y,
+		double thetaMarked, double minThetaMarked, 
+		int threshold, 
+		int th_hip, int th_knee, int th_toe,
+		int th_size_hip, int th_size_knee, int th_size_toe, 
+		int thresholdLargestContour, bool contour)
+{
+	char *label = new char[150];
+	int width = img->width;
+	int height = img->height;
+
+	int x;
+	if(labelsAtLeft)
+		x=10;
+	else
+		x=width-200;
+				
+	sprintf(label, "frame: %d", framesCount);
+	cvPutText(img, label, cvPoint(x,height-210),&font,color);
+
+	sprintf(label, "H(%d,%d)", hip_x, hip_y);
+	cvPutText(img, label, cvPoint(x,height-180),&font,color);
+	sprintf(label, "K(%d,%d)", knee_x, knee_y);
+	cvPutText(img, label, cvPoint(x,height-160),&font,color);
+	sprintf(label, "T(%d,%d)", toe_x, toe_y);
+	cvPutText(img, label, cvPoint(x,height-140),&font,color);
+	
+	sprintf(label, "angle curr. (min):");
+	cvPutText(img, label, cvPoint(x,height-110),&font,color);
+	
+	sprintf(label, "%.2f (%.2f)", thetaMarked, minThetaMarked);
+	cvPutText(img, label, cvPoint(x,height-90),&font,color);
+	
+	if (contour) {
+		sprintf(label, "threshold: %d", thresholdLargestContour);
+		cvPutText(img, label, cvPoint(x,height-60),&font,color);
+	}
+	else {
+		sprintf(label, "threshold: %d", threshold);
+		cvPutText(img, label, cvPoint(x,height-60),&font,color);
+
+		sprintf(label, "HKT: %d, %d, %d", th_hip, th_knee, th_toe);
+		cvPutText(img, label, cvPoint(x,height-40),&font,color);
+	
+		sprintf(label, "Sizes: %d, %d, %d", th_size_hip, th_size_knee, th_size_toe);
+		cvPutText(img, label, cvPoint(x,height-20),&font,color);
+	}
+}
+
+//for blackWithoutMarkers
+void printOnScreenBWM(IplImage * img, CvFont font, CvScalar color, bool labelsAtLeft, 
+		int framesCount, double rectHP, double kpfY) {
+	char *label = new char[150];
+	int width = img->width;
+	int height = img->height;
+	int x;
+	if(labelsAtLeft)
+		x=10;
+	else
+		x=width-200;
+				
+	sprintf(label, "frame: %d", framesCount);
+	cvPutText(img, label, cvPoint(x,height-80),&font,color);
+
+	sprintf(label, "rectHP %.3f%%", rectHP);
+	cvPutText(img, label, cvPoint(x,height-60),&font,color);
+	
+	sprintf(label, "kpfY %.3f%%", kpfY);
+	cvPutText(img, label, cvPoint(x,height-40),&font,color);
+}
 		
 /*
 CvSeq * GetRowsCenter(IplImage * img, CvRect maxrect, int starty, int endy)
@@ -1481,4 +1723,3 @@ CvRect findKneeCenterAtExtension(IplImage* img, int y)
 
 	return kneeRect;
 }
-
