@@ -24,6 +24,7 @@ using System.Text; //StringBuilder
 
 using System.Threading;
 using System.IO.Ports;
+using Mono.Unix;
 
 
 public class EventExecute 
@@ -120,6 +121,9 @@ public class EventExecute
 	protected bool finish;
 	protected bool totallyFinished;
 	
+	//if chronopic is disconnected by user, port changes, ...
+	protected bool chronopicDisconnected;
+	
 	// multi Chronopic stuff
 	protected int chronopics; 
 	protected bool totallyFinishedMulti1;
@@ -164,6 +168,9 @@ public class EventExecute
 	{
 		Chronopic.Plataforma myPlatformState  = Chronopic.Plataforma.UNKNOW; //on (in platform), off (jumping), or unknow
 		bool ok = false;
+		int timeWait = 50; //wait 50ms between calls to Read_platform
+		int timeLimit = 1000;
+		int count = 0; 
 
 		do {
 			try {
@@ -171,7 +178,9 @@ public class EventExecute
 			} catch {
 				Log.WriteLine("Manage called after finishing constructor, do later");
 			}
-		} while (! ok);
+			Thread.Sleep(timeWait); //wait 50ms
+			count += timeWait;
+		} while (! ok && count < timeLimit);
 
 		return myPlatformState;
 	}
@@ -269,9 +278,9 @@ public class EventExecute
 			needUpdateEventProgressBar = false;
 		}
 		
-	Console.WriteLine("pulse update graph");	
+//	Console.WriteLine("pulse update graph");	
 		if(needUpdateGraph) {
-	Console.WriteLine("pulse update graph 2");	
+//	Console.WriteLine("pulse update graph 2");	
 			//solve problems when runAnalysis ended and tries to paint window
 			if(needUpdateGraphType == eventType.MULTICHRONOPIC && type == Constants.RunAnalysisName && finish) 
 				Console.WriteLine("is MC, RA, finished!");	
@@ -281,10 +290,10 @@ public class EventExecute
 			} else
 				updateGraph();
 	
-			Console.WriteLine("pulse update graph 3");	
+//			Console.WriteLine("pulse update graph 3");	
 			needUpdateGraph = false;
 		}
-	Console.WriteLine("pulse update graph 4");	
+//	Console.WriteLine("pulse update graph 4");	
 		
 		if(needSensitiveButtonFinish) {
 			eventExecuteWin.ButtonFinishMakeSensitive();
@@ -302,7 +311,7 @@ public class EventExecute
 			finish = true;
 			updateProgressBarForFinish();
 		} 
-	Console.WriteLine("pulse done");	
+//	Console.WriteLine("pulse done");	
 		//else 
 		//	updateTimeProgressBar();
 	}
@@ -322,7 +331,7 @@ public class EventExecute
 		
 		//if the time is too much, finish
 		if(timerCount - simulatedTimeAccumulatedBefore > timeMax) {
-				Log.WriteLine("EXCEEDES MAX!");
+//				Log.WriteLine("EXCEEDES MAX!");
 				simulateChangePlatform();
 		}
 		
@@ -336,7 +345,7 @@ public class EventExecute
 			//double dice = 0;
 			double myRand = rand.NextDouble();
 			double dice = myRand * (simulatedRange *10 +1);
-			Log.WriteLine(string.Format("rand: {0}, dice: {1}", myRand, dice));
+//			Log.WriteLine(string.Format("rand: {0}, dice: {1}", myRand, dice));
 			if (dice < 1)
 			{
 				simulateChangePlatform();
@@ -444,7 +453,6 @@ public class EventExecute
 	protected virtual void write() {
 	}
 
-
 	protected virtual void goodEvent() {
 		Util.PlaySound(Constants.SoundTypes.GOOD, volumeOn);
 	} 
@@ -464,6 +472,16 @@ public class EventExecute
 		//event will be raised, and managed in chronojump.cs
 		fakeButtonFinished.Click();
 	}
+
+	protected void chronopicHasBeenDisconnected() {
+		chronopicDisconnected = true;
+		ErrorWindow errorWin;		
+		errorWin = ErrorWindow.Show( 
+				Catalog.GetString("Chronopic seems disconnected. Reconnect again on Chronopic Window."));
+
+		Util.PlaySound(Constants.SoundTypes.BAD, volumeOn);
+		errorWin.Button_accept.Clicked += new EventHandler(cancel_event_before_start);
+	}
 	
 	public virtual bool MultiChronopicRunAUsedCP2() {
 		return false;
@@ -505,6 +523,11 @@ public class EventExecute
 		set { totallyFinished = value; }
 	}
 
+	public bool ChronopicDisconnected
+	{
+		get { return chronopicDisconnected; }
+	}
+
 	public Event EventDone {
 		get { return eventDone; }
 	}
