@@ -110,6 +110,9 @@ public class JumpExecute : EventExecute
 	
 	public override void Manage()
 	{
+		//boolean to know if chronopic has been disconnected	
+		chronopicDisconnected = false;
+
 		if (simulated) 
 			platformState = Chronopic.Plataforma.ON;
 		else
@@ -125,7 +128,7 @@ public class JumpExecute : EventExecute
 			//prepare jump for being cancelled if desired
 			cancel = false;
 			totallyCancelled = false;
-
+	
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			//mark now that we have leaved platform:
 			if (simulated)
@@ -137,7 +140,7 @@ public class JumpExecute : EventExecute
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 			thread.Start(); 
 		} 
-		else {
+		else if (platformState==Chronopic.Plataforma.OFF) {
 			ConfirmWindow confirmWin;		
 			confirmWin = ConfirmWindow.Show( 
 					Catalog.GetString("You are OUT, come inside and press the 'accept' button"), "", "");
@@ -147,13 +150,19 @@ public class JumpExecute : EventExecute
 			//we call again this function
 			confirmWin.Button_accept.Clicked += new EventHandler(callAgainManage);
 			
-			//if confirmWin.Button_cancel is pressed retuen
+			//if confirmWin.Button_cancel is pressed return
 			confirmWin.Button_cancel.Clicked += new EventHandler(cancel_event_before_start);
 		}
+		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+			chronopicHasBeenDisconnected();
+		}
 	}
 
 	public override void ManageFall()
 	{
+		//boolean to know if chronopic has been disconnected	
+		chronopicDisconnected = false;
+
 		if (simulated) 
 			platformState = Chronopic.Plataforma.OFF;
 		else
@@ -173,8 +182,6 @@ public class JumpExecute : EventExecute
 			cancel = false;
 			totallyCancelled = false;
 
-
-
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			//mark now that we have arrived:
 			if (simulated)
@@ -185,7 +192,7 @@ public class JumpExecute : EventExecute
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 			thread.Start(); 
 		} 
-		else {
+		else if (platformState==Chronopic.Plataforma.ON) {
 			ConfirmWindow confirmWin;		
 			confirmWin = ConfirmWindow.Show( 
 					Catalog.GetString("You are IN, please leave the platform, and press the 'accept' button"), "", "");
@@ -197,6 +204,9 @@ public class JumpExecute : EventExecute
 			//if confirmWin.Button_cancel is pressed return
 			confirmWin.Button_cancel.Clicked += new EventHandler(cancel_event_before_start);
 		}
+		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+			chronopicHasBeenDisconnected();
+		}
 	}
 	
 	//for calling it again after a confirmWindow says that you have to be in or out the platform
@@ -500,6 +510,9 @@ public class JumpRjExecute : JumpExecute
 
 	public override void Manage()
 	{
+		//boolean to know if chronopic has been disconnected	
+		chronopicDisconnected = false;
+
 		if (simulated)
 			if(hasFall) 
 				platformState = Chronopic.Plataforma.OFF;
@@ -510,8 +523,12 @@ public class JumpRjExecute : JumpExecute
 
 		if(platformState == Chronopic.Plataforma.OFF)
 			loggedState = States.OFF;
-		else
+		else if(platformState == Chronopic.Plataforma.ON)
 			loggedState = States.ON;
+		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+			chronopicHasBeenDisconnected();
+			return;
+		}
 
 		
 		bool success = false;
@@ -561,7 +578,7 @@ public class JumpRjExecute : JumpExecute
 			//prepare jump for being finished earlier if desired
 			finish = false;
 			totallyFinished = false;
-
+			
 			//in simulated mode, make the jump start just when we arrive to waitEvent at the first time
 			//mark now that the opposite as before:
 			if (simulated) {
@@ -910,7 +927,7 @@ public class JumpRjExecute : JumpExecute
 		}
 
 		if(type == Constants.RunAnalysisName) {
-			double speed = (fall /10) / Util.GetTotalTime(tcString, tvString);
+			//double speed = (fall /10) / Util.GetTotalTime(tcString, tvString);
 	
 	/*		
 	 *		Josep Ma Padullés test
