@@ -106,6 +106,8 @@ public class PulseExecute : EventExecute
 	{
 		bool success = false;
 		
+		//boolean to know if chronopic has been disconnected	
+		chronopicDisconnected = false;
 		
 		if (simulated) 
 			platformState = Chronopic.Plataforma.OFF;
@@ -125,7 +127,10 @@ public class PulseExecute : EventExecute
 
 			//we call again this function
 			confirmWin.Button_accept.Clicked += new EventHandler(callAgainManage);
-		} else {
+			
+			//if confirmWin.Button_cancel is pressed retuen
+			confirmWin.Button_cancel.Clicked += new EventHandler(cancel_event_before_start);
+		} else if (platformState==Chronopic.Plataforma.OFF) {
 			appbar.Push( 1, Catalog.GetString("You are OUT, start when prepared!!") );
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 
@@ -133,6 +138,10 @@ public class PulseExecute : EventExecute
 
 			success = true;
 		}
+		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+			chronopicHasBeenDisconnected();
+			return;
+		}
 
 		if(success) {
 			//initialize variables
