@@ -97,6 +97,7 @@ public class ChronopicWindow
 		OFF
 	}
 	bool connected;
+	bool volumeOn;
 	int currentCp; //1 to 4
 
 	//cp1	
@@ -106,17 +107,14 @@ public class ChronopicWindow
 	
 	//cp2	
 	Chronopic cp2;
-	SerialPort sp2;
 	Chronopic.Plataforma platformState2;
 
 	//cp3	
 	Chronopic cp3;
-	SerialPort sp3;
 	Chronopic.Plataforma platformState3;
 
 	//cp4	
 	Chronopic cp4;
-	SerialPort sp4;
 	Chronopic.Plataforma platformState4;
 
 	States loggedState;		//log of last state
@@ -128,7 +126,7 @@ public class ChronopicWindow
 		gxml = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "chronopic_window", null);
 		gxml.Autoconnect(this);
 
-		cpd=myCpd;
+		cpd = myCpd;
 			
 		UtilGtk.IconWindow(chronopic_window);
 
@@ -152,28 +150,31 @@ public class ChronopicWindow
 		*/
 	}
 	
-	static public ChronopicWindow Create (ArrayList myCpd)
+	//recreate is used when a Chronopic was disconnected
+	static public ChronopicWindow Create (ArrayList myCpd, bool recreate, bool volumeOn)
 	{
-		if (ChronopicWindowBox == null) {
+		if (ChronopicWindowBox == null || recreate) {
 			ChronopicWindowBox = new ChronopicWindow (myCpd);
-
-		//put an icon to window
 		}
 		
 		//don't show until View is called
 		//ChronopicWindowBox.chronopic_window.Show ();
+		
+		ChronopicWindowBox.volumeOn = volumeOn;
 
 		ChronopicWindowBox.fakeWindowDone = new Gtk.Button();
 		
 		return ChronopicWindowBox;
 	}
 
-	static public ChronopicWindow View ()
+	static public ChronopicWindow View (bool volumeOn)
 	{
 		if (ChronopicWindowBox == null) {
 			ChronopicWindowBox = new ChronopicWindow (cpd);
 		}
 		
+		ChronopicWindowBox.volumeOn = volumeOn;
+		ChronopicWindowBox.checkChronopicDisconnected();
 		ChronopicWindowBox.createCombos();
 		ChronopicWindowBox.chronopic_window.Show();
 	
@@ -213,6 +214,52 @@ public class ChronopicWindow
 		image_cp4_yes.Hide();
 	}
 	
+	//check if user has disconnected chronopic or port has changed
+	private void checkChronopicDisconnected() {
+		foreach(ChronopicPortData a in cpd) {
+			Chronopic myCP;
+			Chronopic.Plataforma myPS;
+			if(a.Num == 1) {
+				myCP = cp;
+				myPS = platformState;
+			} else if(a.Num == 2) {
+				myCP = cp2;
+				myPS = platformState2;
+			} else if(a.Num == 3) {
+				myCP = cp3;
+				myPS = platformState3;
+			} else { //if(a.Num == 4) {
+				myCP = cp4;
+				myPS = platformState4;
+			}
+			
+			int errorCount = 0;
+			bool ok = false;	
+			if(a.Connected) {
+				//try {
+					ok = myCP.Read_platform(out myPS);
+				//} catch { 
+				//	Log.WriteLine("catch at 1"); 
+				//}
+				if(!ok) {
+					Log.WriteLine("false at 1");
+					errorCount ++;
+				}
+			}
+			if(errorCount > 0) {
+				ArrayList myCPD = new ArrayList();
+				for(int i=1; i<=4;i++) {
+					ChronopicPortData b = new ChronopicPortData(i,"",false);
+					myCPD.Add(b);
+				}
+				Create (myCPD, true, volumeOn);
+				new DialogMessage(Constants.MessageTypes.WARNING, 
+						Catalog.GetString("One or more Chronopics have been disconnected.") + "\n" + 
+						Catalog.GetString("Please connect again, and configure on Chronopic window."));
+			}
+		}
+	}
+	
 	private void createCombos() {
 		if(isWindows)
 			ChronopicWindowBox.createComboWindows();
@@ -224,7 +271,6 @@ public class ChronopicWindow
 	private void createComboWindows() {
 		//combo port stuff
 		comboWindowsOptions = new string[257];
-		int count = 0;
 		for (int i=1; i <= 257; i ++)
 			comboWindowsOptions[i-1] = "COM" + i;
 	
@@ -435,7 +481,6 @@ public class ChronopicWindow
 	
 
 	private void on_button_connect_cp_clicked (object o, EventArgs args) {
-		Button btn = o as Button;
 		if (o == null)
 			return;
 
@@ -506,6 +551,10 @@ public class ChronopicWindow
 			if(connected)
 				return;
 		}
+	
+		SerialPort sp2;
+		SerialPort sp3;
+		SerialPort sp4;
 
 		string message = "";
 		string myPort = "";
@@ -609,9 +658,11 @@ public class ChronopicWindow
 		Log.WriteLine(string.Format("wait_chronopic_start {0}", message));
 			
 		if(success) {
+			Util.PlaySound(Constants.SoundTypes.GOOD, volumeOn);
 			updateChronopicWinValuesState= true; //connected
 			updateChronopicWinValuesMessage= message;
 		} else {
+			Util.PlaySound(Constants.SoundTypes.BAD, volumeOn);
 			updateChronopicWinValuesState= false; //disconnected
 			updateChronopicWinValuesMessage= message;
 		}
