@@ -819,6 +819,8 @@ public class PersonAddModifyWindow
 
 	[Widget] Gtk.SpinButton spinbutton_height;
 	[Widget] Gtk.SpinButton spinbutton_weight;
+	[Widget] Gtk.Button button_height_metric;
+	[Widget] Gtk.Button button_weight_metric;
 	
 	[Widget] Gtk.Box hbox_combo_sports;
 	[Widget] Gtk.ComboBox combo_sports;
@@ -853,7 +855,6 @@ public class PersonAddModifyWindow
 	static PersonAddModifyWindow PersonAddModifyWindowBox;
 	
 	Gtk.Window parent;
-	ErrorWindow errorWin;
 	
 	DialogCalendar myDialogCalendar;
 	DateTime dateTime;
@@ -1228,9 +1229,33 @@ public class PersonAddModifyWindow
 		label_date.Text = dateTime.ToLongDateString();
 		on_entries_required_changed(new object(), new EventArgs());
 	}
+	
+	void on_button_height_metric_clicked(object obj, EventArgs args) 
+	{
+		genericWin = GenericWindow.Show(Catalog.GetString("Select your height"), Constants.GenericWindowShow.HEIGHTMETRIC);
+		genericWin.Button_accept.Clicked += new EventHandler(on_button_height_metric_accepted);
+	}
+	void on_button_height_metric_accepted (object obj, EventArgs args)
+	{
+		string [] myStr = genericWin.TwoSpinSelected.Split(new char[] {':'});
+		spinbutton_height.Value = Util.ConvertFeetInchesToCm(
+			Convert.ToInt32(myStr[0]), 
+			Convert.ToDouble(myStr[1])
+		);
+	}
+	
+	void on_button_weight_metric_clicked(object obj, EventArgs args) 
+	{
+		genericWin = GenericWindow.Show(Catalog.GetString("Select your weight in pounds"), Constants.GenericWindowShow.SPINDOUBLE);
+		genericWin.Button_accept.Clicked += new EventHandler(on_button_weight_metric_accepted);
+	}
+	void on_button_weight_metric_accepted (object obj, EventArgs args)
+	{
+		spinbutton_weight.Value = Util.ConvertPoundsToKg(genericWin.SpinDoubleSelected);
+	}
+
 
 	private void on_combo_sports_changed(object o, EventArgs args) {
-		ComboBox combo = o as ComboBox;
 		if (o == null)
 			return;
 
@@ -1437,7 +1462,6 @@ public class PersonAddModifyWindow
 				if(myJumpsNormal.Length > 0 || myJumpsReactive.Length > 0) {
 					//create the convertWeight Window
 					convertWeightWin = ConvertWeightWindow.Show(
-							currentSession.UniqueID, currentPerson.UniqueID, 
 							weightIni, (double) spinbutton_weight.Value, 
 							myJumpsNormal, myJumpsReactive);
 					convertWeightWin.Button_accept.Clicked += new EventHandler(on_convertWeightWin_accepted);
@@ -1451,7 +1475,7 @@ public class PersonAddModifyWindow
 		}
 
 		if(errorMessage.Length > 0)
-			errorWin = ErrorWindow.Show(errorMessage);
+			ErrorWindow.Show(errorMessage);
 	}
 
 	void on_convertWeightWin_accepted (object o, EventArgs args) {
@@ -1486,8 +1510,7 @@ public class PersonAddModifyWindow
 					Constants.RaceUndefinedID,
 					Convert.ToInt32(Util.FindOnArray(':', 2, 0, UtilGtk.ComboGetActive(combo_countries), countries)),
 					textview_description.Buffer.Text,
-					Constants.ServerUndefinedID,
-					currentSession.UniqueID);
+					Constants.ServerUndefinedID);
 					
 			currentPersonSession = new PersonSession (
 					currentPerson.UniqueID, currentSession.UniqueID, 
@@ -1615,7 +1638,6 @@ public class PersonAddMultipleWindow {
 	
 	static PersonAddMultipleWindow PersonAddMultipleWindowBox;
 	Gtk.Window parent;
-	ErrorWindow errorWin;
 
 	private Person currentPerson;
 	Session currentSession;
@@ -1755,7 +1777,7 @@ public class PersonAddMultipleWindow {
 		combinedErrorString = readErrorStrings();
 		
 		if (combinedErrorString.Length > 0) {
-			errorWin = ErrorWindow.Show(combinedErrorString);
+			ErrorWindow.Show(combinedErrorString);
 		} else {
 			prepareAllNonBlankRows();
 		
@@ -1837,11 +1859,10 @@ public class PersonAddMultipleWindow {
 				Constants.RaceUndefinedID,
 				Constants.CountryUndefinedID,
 				"", 			//description
-				Constants.ServerUndefinedID,
-				currentSession.UniqueID);
+				Constants.ServerUndefinedID);
 				
 
-		PersonSession ps = new PersonSession (
+		new PersonSession (
 				currentPerson.UniqueID, currentSession.UniqueID, 
 				0, weight, 		//height, weight	
 				currentSession.PersonsSportID,
