@@ -528,7 +528,6 @@ public class QueryServerWindow
 
 
 	private void on_combo_sports_changed(object o, EventArgs args) {
-		ComboBox combo = o as ComboBox;
 		if (o == null)
 			return;
 
@@ -746,8 +745,10 @@ public class QueryServerWindow
 				label_results_num.Text = resultFull[0];
 				if(resultFull[0] == "0")
 					label_results_avg.Text = "-";
-				else
-					label_results_avg.Text = Util.TrimDecimals(resultFull[1], pDN);
+				else {
+					label_results_avg.Text = Util.TrimDecimals(
+						Util.ConvertToPointIfNeeded(resultFull[1]), pDN);
+}
 			}
 
 			return sqlString;
