@@ -85,6 +85,9 @@ public class StatsWindow {
 	[Widget] Gtk.ComboBox combo_graph_palette;
 	[Widget] Gtk.Label label_graph_options;
 	[Widget] Gtk.CheckButton checkbutton_transposed;
+	[Widget] Gtk.Box hbox_line;
+	[Widget] Gtk.SpinButton spin_line;
+
 	[Widget] Gtk.Box hbox_combo_graph_width;
 	[Widget] Gtk.Box hbox_combo_graph_height;
 	[Widget] Gtk.ComboBox combo_graph_width;
@@ -108,7 +111,6 @@ public class StatsWindow {
 	bool statsAutomatic = false;
 	bool statsColumnsToRemove = false;
 	private Session currentSession;
-	bool changingCombos = false;
 	//selected sessions
 	ArrayList selectedSessions;
 	
@@ -423,9 +425,12 @@ public class StatsWindow {
 	}
 	
 	private void showTransposed(bool show) {
-		//label_graph_options.Visible = show;
 		checkbutton_transposed.Visible = show;
 	}
+	
+	private void showLineWidth(bool show) {
+		hbox_line.Visible = show;
+	}
 
 	private void showGraphXYStuff(bool show) {
 		label_graph_var_x.Visible = show;
@@ -439,6 +444,8 @@ public class StatsWindow {
 			showGraphXYStuff(true);
 		else 
 			showGraphXYStuff(false);
+		
+		showLineWidth(true);
 
 		if(
 				UtilGtk.ComboGetActive(combo_graph_type) == Constants.GraphTypeDotchart ||
@@ -673,6 +680,7 @@ public class StatsWindow {
 				UtilGtk.ComboGetActive(combo_graph_var_y),
 				UtilGtk.ComboGetActive(combo_graph_palette),
 				checkbutton_transposed.Active,
+				Convert.ToInt32(spin_line.Value), 
 				Convert.ToInt32(UtilGtk.ComboGetActive(combo_graph_width)),
 				Convert.ToInt32(UtilGtk.ComboGetActive(combo_graph_height)),
 				UtilGtk.ComboGetActive(combo_graph_legend),
